@@ -24,14 +24,7 @@ Once all services have been deployed and their VirtualNodes are setup, we deploy
 from troposphere import Ref, GetAtt, AWS_ACCOUNT_ID, AWS_STACK_NAME
 from troposphere import appmesh
 
-from ecs_composex.appmesh import appmesh_params, appmesh_conditions
-from ecs_composex.appmesh import metadata
-from ecs_composex.appmesh.appmesh_aws import lookup_mesh_by_name
-from ecs_composex.appmesh.appmesh_conditions import add_appmesh_conditions
-from ecs_composex.appmesh.appmesh_node import MeshNode
-from ecs_composex.appmesh.appmesh_params import MESH_NAME, MESH_OWNER_ID
-from ecs_composex.appmesh.appmesh_router import MeshRouter
-from ecs_composex.appmesh.appmesh_service import MeshService
+from ecs_composex.resources_import import import_record_properties
 from ecs_composex.common import (
     keyisset,
     add_parameters,
@@ -40,7 +33,15 @@ from ecs_composex.common import (
 from ecs_composex.common.cfn_params import ROOT_STACK_NAME
 from ecs_composex.common.stacks import ComposeXStack
 from ecs_composex.ecs import ecs_params
-from ecs_composex.ecs.ecs_template import get_service_family_name
+
+from ecs_composex.appmesh import appmesh_params, appmesh_conditions
+from ecs_composex.appmesh import metadata
+from ecs_composex.appmesh.appmesh_aws import lookup_mesh_by_name
+from ecs_composex.appmesh.appmesh_conditions import add_appmesh_conditions
+from ecs_composex.appmesh.appmesh_node import MeshNode
+from ecs_composex.appmesh.appmesh_params import MESH_NAME, MESH_OWNER_ID
+from ecs_composex.appmesh.appmesh_router import MeshRouter
+from ecs_composex.appmesh.appmesh_service import MeshService
 
 
 class Mesh(object):
@@ -49,14 +50,12 @@ class Mesh(object):
     """
 
     mesh_title = "ServiceMesh"
-    nodes_key = "nodes"
-    routers_key = "routers"
-    services_key = "services"
+    nodes_key = appmesh_params.NODES_KEY
+    routers_key = appmesh_params.ROUTERS_KEY
+    services_key = appmesh_params.SERVICES_KEY
     required_keys = [nodes_key, routers_key, services_key]
 
-    def __init__(
-        self, mesh_definition, services_families, services_root_stack, settings
-    ):
+    def __init__(self, mesh_definition, services_root_stack, settings):
         """
         Method to initialize the Mesh
 
@@ -97,31 +96,19 @@ class Mesh(object):
                 }
             )
         else:
-            self.mesh_name = MESH_NAME.Default
-            allowed_values = ["ALLOW_ALL", "DROP_ALL"]
-            egress_type = "DROP_ALL"
-            if (
-                keyisset("EgressFilter", self.mesh_properties)
-                and self.mesh_properties["EgressFilter"] in allowed_values
-            ):
-                egress_type = self.mesh_properties["EgressFilter"]
-            elif (
-                keyisset("EgressFilter", self.mesh_properties)
-                and self.mesh_properties["EgressFilter"] not in allowed_values
-            ):
-                LOG.warning(
-                    f"Invalid EgressFilter value {self.mesh_properties['EgressFilter']}."
-                    f" Allowed values: {allowed_values} "
-                    "Setting to default: DROP_ALL"
-                )
+            if self.mesh_properties:
+                props = import_record_properties(self.mesh_properties, appmesh.Mesh)
+                props["Metadata"] = metadata
+                props["MeshName"] = appmesh_conditions.set_mesh_name()
+            else:
+                props = {
+                    "Spec": appmesh.MeshSpec(
+                        EgressFilter=appmesh.EgressFilter(Type="DENY_ALL")
+                    ),
+                    "MeshName": appmesh_conditions.set_mesh_name(),
+                }
             self.appmesh = appmesh.Mesh(
-                self.mesh_title,
-                template=services_root_stack.stack_template,
-                MeshName=appmesh_conditions.set_mesh_name(),
-                Spec=appmesh.MeshSpec(
-                    EgressFilter=appmesh.EgressFilter(Type=egress_type)
-                ),
-                Metadata=metadata,
+                self.mesh_title, template=services_root_stack.stack_template, **props
             )
             services_root_stack.Parameters.update(
                 {
@@ -132,11 +119,11 @@ class Mesh(object):
         for key in self.required_keys:
             if key not in self.mesh_settings.keys():
                 raise KeyError(f"Key {key} is missing. Required {self.required_keys}")
-        self.define_nodes(services_families, services_root_stack)
+        self.define_nodes(settings, services_root_stack, self.appmesh)
         self.define_routes_and_routers()
         self.define_virtual_services()
 
-    def define_nodes(self, services_families, services_root_stack):
+    def define_nodes(self, settings, services_root_stack, mesh):
         """
         Method to compile the nodes for the Mesh.
 
@@ -144,30 +131,48 @@ class Mesh(object):
         :type services_root_stack: ecs_composex.ecs.ServicesStack
         :return:
         """
-        nodes_keys = ["name", "protocol", "backends"]
-        for node in self.mesh_settings["nodes"]:
+        nodes_keys = [
+            appmesh_params.NAME_KEY,
+            appmesh_params.PROTOCOL_KEY,
+            appmesh_params.BACKENDS_KEY,
+        ]
+        for node in self.mesh_settings[self.nodes_key]:
             if not set(node.keys()).issubset(nodes_keys):
                 raise AttributeError(
                     f"Nodes must have set {nodes_keys}. Got", node.keys()
                 )
-            service_family = get_service_family_name(services_families, node["name"])
-            LOG.debug(service_family)
-            if service_family not in services_root_stack.stack_template.resources:
-                raise AttributeError(
-                    f"Node defined {service_family} is not defined in services stack",
-                    services_root_stack.stack_template.resources,
+            service_families = [
+                settings.families[name]
+                for name in settings.families
+                if settings.families[name].name == node[appmesh_params.NAME_KEY]
+            ]
+            if len(service_families) > 1:
+                raise LookupError(
+                    "More than one family matched for the node.",
+                    service_families,
+                    node[appmesh_params.NAME_KEY],
+                )
+            elif not service_families:
+                raise LookupError(
+                    "No family could be matched for the given node",
+                    settings.families,
+                    node[appmesh_params.NAME_KEY],
                 )
             LOG.debug(node)
-            self.nodes[service_family] = MeshNode(
-                services_root_stack.stack_template.resources[service_family],
-                node["protocol"],
-                node["backends"] if keyisset("backends", node) else None,
+            family = service_families[0]
+            self.nodes[family.logical_name] = MeshNode(
+                family,
+                node[appmesh_params.PROTOCOL_KEY],
+                mesh,
+                node[appmesh_params.BACKENDS_KEY]
+                if keyisset(appmesh_params.BACKENDS_KEY, node)
+                else None,
             )
-            self.nodes[service_family].get_node_param = GetAtt(
-                self.nodes[service_family].param_name, "Outputs.VirtualNode"
+            self.nodes[family.logical_name].get_node_param = GetAtt(
+                self.nodes[family.logical_name].param_name, "Outputs.VirtualNode"
             )
-            self.nodes[service_family].get_sg_param = GetAtt(
-                self.nodes[service_family].param_name,
+            self.nodes[family.logical_name].get_sg_param = GetAtt(
+                self.nodes[family.logical_name].param_name,
                 f"Outputs.{ecs_params.SERVICE_GROUP_ID_T}",
             )
 
@@ -175,18 +180,18 @@ class Mesh(object):
         """
         Method to register routers
         """
-        for router in self.mesh_settings["routers"]:
-            name = router["name"]
+        for router in self.mesh_settings[self.routers_key]:
+            name = router[appmesh_params.NAME_KEY]
             self.routers[name] = MeshRouter(
-                router["name"], router, self.appmesh, self.nodes
+                router[appmesh_params.NAME_KEY], router, self.appmesh, self.nodes
             )
 
     def define_virtual_services(self):
         """
         Method to parse the services and map them to nodes and routers.
         """
-        for service in self.mesh_settings["services"]:
-            name = service["name"]
+        for service in self.mesh_settings[self.services_key]:
+            name = service[appmesh_params.NAME_KEY]
             self.services[name] = MeshService(
                 name, service, self.routers, self.nodes, self.appmesh
             )
