@@ -69,6 +69,7 @@ class ComposeXStack(Stack, object):
         "UpdatePolicy",
         "UpdateReplacePolicy",
     ]
+    is_void = False
 
     def __init__(
         self, title, stack_template, stack_parameters=None, file_name=None, **kwargs
@@ -193,6 +194,7 @@ class ComposeXStack(Stack, object):
         Function to use when the template is finalized and can be uploaded to S3.
         """
         LOG.debug(f"Rendering {self.title}")
+        self.DependsOn = list(set(self.DependsOn))
         template_file = FileArtifact(
             file_name=self.file_name,
             template=self.stack_template,
@@ -290,6 +292,6 @@ def process_stacks(root_stack, settings):
             process_stacks(resource, settings)
             resource.Parameters.update(cfn_conditions.pass_root_stack_name())
         elif isinstance(resource, Stack):
-            LOG.warn(resource_name)
-            LOG.warn(resource)
+            LOG.warning(resource_name)
+            LOG.warning(resource)
     root_stack.render(settings)
