@@ -19,9 +19,14 @@
 Module for DNS parameters
 """
 
+from os import path
 from troposphere import Parameter, Sub
 
-ZONES_PATTERN = r"^none$|^ns-[a-z0-9]{6,24}$"
+MOD_KEY = path.basename(path.dirname(path.abspath(__file__)))
+RES_KEY = f"x-{path.basename(path.dirname(path.abspath(__file__)))}"
+
+
+ZONES_PATTERN = r"^none$|^ns-[a-z0-9]{6,24}$|^Z[0-9A-Z]+$"
 
 PUBLIC_DNS_ZONE_NAME_T = "PublicDnsZoneName"
 PUBLIC_DNS_ZONE_NAME = Parameter(
