@@ -22,7 +22,7 @@ from troposphere import Parameter
 TABLE_NAME_T = "DynamoDbTableName"
 TABLE_NAME = Parameter(TABLE_NAME_T, Type="String", AllowedPattern=r"[a-zA-Z0-9_.-]+")
 
-TABLE_ARN_T = "DynamoDbTableArn"
+TABLE_ARN_T = "Arn"
 TABLE_ARN = Parameter(TABLE_ARN_T, Type="String")
 
 RES_KEY = f"{X_KEY}{path.basename(path.dirname(path.abspath(__file__)))}"
