@@ -17,19 +17,19 @@
 #   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from botocore.exceptions import ClientError
-
-from troposphere import If, Ref
 from troposphere import AWS_STACK_NAME
+from troposphere import If, Ref
 from troposphere.ecs import Cluster, CapacityProviderStrategyItem
 
+from ecs_composex.resources_import import import_record_properties
 from ecs_composex.common import LOG, keyisset
+from ecs_composex.ecs import metadata
 from ecs_composex.ecs.ecs_conditions import (
     GENERATED_CLUSTER_NAME_CON_T,
+    CREATE_CLUSTER_CON_T,
     GENERATED_CLUSTER_NAME_CON,
 )
-from ecs_composex.ecs.ecs_params import CLUSTER_NAME_T, CLUSTER_T
-from ecs_composex.ecs import metadata
-
+from ecs_composex.ecs.ecs_params import CLUSTER_NAME, CLUSTER_T, CREATE_CLUSTER
 
 RES_KEY = "x-cluster"
 FARGATE_PROVIDER = "FARGATE"
@@ -53,8 +53,9 @@ def get_default_cluster_config():
 
     return Cluster(
         CLUSTER_T,
+        Condition=CREATE_CLUSTER_CON_T,
         ClusterName=If(
-            GENERATED_CLUSTER_NAME_CON_T, Ref(AWS_STACK_NAME), Ref(CLUSTER_NAME_T)
+            GENERATED_CLUSTER_NAME_CON_T, Ref(AWS_STACK_NAME), Ref(CLUSTER_NAME.title)
         ),
         CapacityProviders=DEFAULT_PROVIDERS,
         DefaultCapacityProviderStrategy=DEFAULT_STRATEGY,
@@ -81,13 +82,13 @@ def lookup_ecs_cluster(session, cluster_lookup):
             LOG.warning(
                 f"No cluster named {cluster_lookup} found. Creating one with default settings"
             )
-            return get_default_cluster_config()
+            return None
         elif (
             keyisset("clusters", cluster_r)
             and cluster_r["clusters"][0]["clusterName"] == cluster_lookup
         ):
             LOG.info(
-                f"Found ECS Cluster {cluster_lookup}. Setting {CLUSTER_NAME_T} accordingly."
+                f"Found ECS Cluster {cluster_lookup}. Setting {CLUSTER_NAME.title} accordingly."
             )
             return cluster_r["clusters"][0]["clusterName"]
     except ClientError as error:
@@ -95,57 +96,25 @@ def lookup_ecs_cluster(session, cluster_lookup):
         raise
 
 
-def import_capacity_strategy(strategy_def):
-    """
-    Function to create the Capacity Provider strategies.
-
-    :param strategy_def:
-    :return:
-    """
-    strategies = []
-    if not isinstance(strategy_def, list):
-        raise ValueError("DefaultCapacityProviderStrategy must be a list")
-    for strategy in strategy_def:
-        strategies.append(CapacityProviderStrategyItem(**strategy))
-    return strategies
-
-
-def define_cluster(root_stack, cluster_def):
+def define_cluster(cluster_def):
     """
     Function to create the cluster from provided properties.
 
     :param dict cluster_def:
-    :param ecs_composex.common.stacks.ComposeXStack root_stack:
     :return: cluster
     :rtype: troposphere.ecs.Cluster
     """
-    cluster_params = {}
-    if not keyisset("Properties", cluster_def):
-        return get_default_cluster_config()
-    props = cluster_def["Properties"]
-    if keyisset("ClusterName", props):
-        root_stack.Parameters.update({CLUSTER_NAME_T: props["ClusterName"]})
-    if not keyisset("CapacityProviders", props):
-        LOG.warning("No capacity providers defined. Setting it to default.")
-        cluster_params["CapacityProviders"] = DEFAULT_PROVIDERS
-    else:
-        cluster_params["CapacityProviders"] = props["CapacityProviders"]
-    if not keyisset("DefaultCapacityProviderStrategy", props):
-        LOG.warning("No Default Strategy set. Setting to default.")
-        cluster_params["DefaultCapacityProviderStrategy"] = DEFAULT_STRATEGY
-    else:
-        cluster_params["DefaultCapacityProviderStrategy"] = import_capacity_strategy(
-            props["DefaultCapacityProviderStrategy"]
-        )
-    cluster_params["Metadata"] = metadata
-    cluster_params["ClusterName"] = If(
-        GENERATED_CLUSTER_NAME_CON_T, Ref(AWS_STACK_NAME), Ref(CLUSTER_NAME_T)
+    compose_props = cluster_def["Properties"]
+    props = import_record_properties(compose_props, Cluster)
+    props["Metadata"] = metadata
+    props["ClusterName"] = (
+        Ref(AWS_STACK_NAME) if not keyisset("ClusterName", props) else Ref(CLUSTER_NAME)
     )
-    cluster = Cluster(CLUSTER_T, **cluster_params)
+    cluster = Cluster(CLUSTER_T, Condition=CREATE_CLUSTER_CON_T, **props)
     return cluster
 
 
-def generate_cluster(root_stack, settings):
+def handle_cluster_settings(root_stack, settings):
     """
     Function to create the ECS Cluster.
 
@@ -153,31 +122,40 @@ def generate_cluster(root_stack, settings):
     :param ecs_composex.common.settings.ComposeXSettings settings:
     :return:
     """
-    cluster = get_default_cluster_config()
     if not keyisset(RES_KEY, settings.compose_content):
-        return cluster
-    if keyisset(RES_KEY, settings.compose_content) and keyisset(
-        "Lookup", settings.compose_content[RES_KEY]
-    ):
-        cluster = lookup_ecs_cluster(
-            settings.session, settings.compose_content[RES_KEY]["Lookup"]
-        )
-    elif keyisset(RES_KEY, settings.compose_content) and isinstance(
-        settings.compose_content[RES_KEY], str
-    ):
-        cluster = settings.compose_content[RES_KEY]
-        LOG.info(f"Using cluster {settings.compose_content[RES_KEY]}")
-
-    elif isinstance(settings.compose_content[RES_KEY], dict) and keyisset(
-        "Use", settings.compose_content[RES_KEY]
-    ):
-        cluster = settings.compose_content[RES_KEY]["Use"]
-        LOG.info(f"Using cluster {settings.compose_content[RES_KEY]['Use']}")
-    elif keyisset(RES_KEY, settings.compose_content) and not keyisset(
-        "Lookup", settings.compose_content[RES_KEY]
-    ):
-        cluster = define_cluster(root_stack, settings.compose_content[RES_KEY])
-    return cluster
+        LOG.info("No cluster information provided. Creating a new one")
+        root_stack.stack_template.add_resource(get_default_cluster_config())
+    elif isinstance(settings.compose_content[RES_KEY], dict):
+        if keyisset("Use", settings.compose_content[RES_KEY]):
+            root_stack.Parameters.update(
+                {
+                    CLUSTER_NAME.title: settings.compose_content[RES_KEY]["Use"],
+                    CREATE_CLUSTER.title: "False",
+                }
+            )
+            LOG.info(f"Using cluster {settings.compose_content[RES_KEY]['Use']}")
+        elif keyisset("Lookup", settings.compose_content[RES_KEY]):
+            cluster_name = lookup_ecs_cluster(
+                settings.session, settings.compose_content[RES_KEY]["Lookup"]
+            )
+            if cluster_name:
+                root_stack.Parameters.update(
+                    {CLUSTER_NAME.title: cluster_name, CREATE_CLUSTER.title: "False"}
+                )
+        elif keyisset("Properties", settings.compose_content[RES_KEY]):
+            cluster = define_cluster(settings.compose_content[RES_KEY])
+            root_stack.stack_template.add_resource(cluster)
+            root_stack.Parameters.update({CREATE_CLUSTER.title: "True"})
+            if keyisset("ClusterName", settings.compose_content[RES_KEY]["Properties"]):
+                root_stack.Parameters.update(
+                    {
+                        CLUSTER_NAME.title: settings.compose_content[RES_KEY][
+                            "Properties"
+                        ]["ClusterName"]
+                    }
+                )
+    if CLUSTER_T not in root_stack.stack_template.resources:
+        root_stack.stack_template.add_resource(get_default_cluster_config())
 
 
 def add_ecs_cluster(settings, root_stack):
@@ -187,13 +165,7 @@ def add_ecs_cluster(settings, root_stack):
     :param ecs_composex.common.settings.ComposeXSettings settings:
     :param ecs_composex.common.stacks.ComposeXStack root_stack:
     """
+    handle_cluster_settings(root_stack, settings)
     root_stack.stack_template.add_condition(
         GENERATED_CLUSTER_NAME_CON_T, GENERATED_CLUSTER_NAME_CON
     )
-    cluster = generate_cluster(root_stack, settings)
-    if isinstance(cluster, Cluster):
-        root_stack.stack_template.add_resource(cluster)
-        return True
-    elif isinstance(cluster, str):
-        root_stack.Parameters.update({CLUSTER_NAME_T: cluster})
-        return False
