@@ -46,6 +46,14 @@ LAUNCH_TYPE = Parameter(
     LAUNCH_TYPE_T, Type="String", AllowedValues=["EC2", "FARGATE"], Default="FARGATE"
 )
 
+FARGATE_VERSION_T = "FargatePlatformVersion"
+FARGATE_VERSION = Parameter(
+    FARGATE_VERSION_T,
+    Type="String",
+    AllowedValues=["DEFAULT", "1.4.0", "1.3.0"],
+    Default="1.4.0",
+)
+
 IS_PUBLIC_T = "ExposeServicePublicly"
 IS_PUBLIC = Parameter(IS_PUBLIC_T, AllowedValues=["True", "False"], Type="String")
 
@@ -54,6 +62,11 @@ CLUSTER_NAME = Parameter(
     CLUSTER_NAME_T, Type="String", AllowedPattern=r"[a-zA-Z0-9-]+", Default="default"
 )
 
+CREATE_CLUSTER_PT = "CreateEcsCluster"
+CREATE_CLUSTER = Parameter(
+    CREATE_CLUSTER_PT, Type="String", AllowedValues=["True", "False"], Default="True"
+)
+
 SERVICE_NAME_T = "MicroServiceName"
 SERVICE_NAME = Parameter(SERVICE_NAME_T, Type="String", AllowedPattern=r"[a-zA-Z0-9-]+")
 
@@ -84,7 +97,12 @@ ECS_CONTROLLER = Parameter(
     Default="ECS",
 )
 
-LOG_GROUP = Parameter(f"Cluster{LOG_GROUP_T}", Type="String")
+CREATE_LOG_GROUP_T = "CreateLogGroup"
+CREATE_LOG_GROUP = Parameter(
+    CREATE_LOG_GROUP_T, Type="String", AllowedValues=["True", "False"], Default="True"
+)
+LOG_GROUP_NAME_T = "ServicesLogGroupName"
+LOG_GROUP_NAME = Parameter(LOG_GROUP_NAME_T, Type="String", Default="ComposeXDefined")
 LOG_GROUP_RETENTION_T = "ServiceLogGroupRetentionPeriod"
 LOG_GROUP_RETENTION = Parameter(
     LOG_GROUP_RETENTION_T,
@@ -146,7 +164,7 @@ CLUSTER_SG_ID = Parameter(
 SERVICE_GROUP_ID_T = "ServiceGroupId"
 SERVICE_GROUP_ID = Parameter(SERVICE_GROUP_ID_T, Type=SG_ID_TYPE, Default="<none>")
 
-AWS_XRAY_IMAGE = "amazon/aws-xray-daemon"
+AWS_XRAY_IMAGE = "public.ecr.aws/w1m2m2a3/aws-xray-daemon:latest"
 XRAY_IMAGE_T = "AWSXRayImage"
 XRAY_IMAGE = Parameter(XRAY_IMAGE_T, Type="String", Default=AWS_XRAY_IMAGE)
 
