@@ -19,14 +19,14 @@
 Core ECS Template building
 """
 
+from troposphere import AWS_ACCOUNT_ID, AWS_PARTITION, AWS_REGION, AWS_NO_VALUE
+from troposphere import If
 from troposphere import Ref, Sub, Tags, GetAtt
 from troposphere.ec2 import SecurityGroup
 from troposphere.iam import PolicyType
 from troposphere.logs import LogGroup
 
-from ecs_composex.common import LOG, NONALPHANUM
 from ecs_composex.common import build_template
-from ecs_composex.common import keyisset
 from ecs_composex.common.cfn_params import (
     ROOT_STACK_NAME_T,
     ROOT_STACK_NAME,
@@ -40,13 +40,12 @@ from ecs_composex.ecs import ecs_conditions, ecs_params
 from ecs_composex.ecs.ecs_params import (
     CLUSTER_NAME,
     CLUSTER_NAME_T,
-    ECS_TASK_FAMILY_LABEL,
 )
 from ecs_composex.ecs.ecs_service import (
     Service,
-    Task,
 )
 from ecs_composex.ecs.ecs_service_config import ServiceConfig
+from ecs_composex.secrets.secrets_params import RES_KEY as SECRETS_KEY
 from ecs_composex.vpc import vpc_params
 
 
@@ -72,14 +71,17 @@ def initialize_service_template(service_name):
             ecs_params.ECS_CONTROLLER,
             ecs_params.SERVICE_COUNT,
             ecs_params.CLUSTER_SG_ID,
-            vpc_params.VPC_ID,
-            vpc_params.APP_SUBNETS,
-            vpc_params.PUBLIC_SUBNETS,
             ecs_params.SERVICE_HOSTNAME,
             ecs_params.FARGATE_CPU_RAM_CONFIG,
             ecs_params.SERVICE_NAME,
             ecs_params.LOG_GROUP_RETENTION,
             ecs_params.ELB_GRACE_PERIOD,
+            ecs_params.FARGATE_VERSION,
+            ecs_params.LOG_GROUP_NAME,
+            ecs_params.CREATE_LOG_GROUP,
+            vpc_params.VPC_ID,
+            vpc_params.APP_SUBNETS,
+            vpc_params.PUBLIC_SUBNETS,
         ],
     )
     service_tpl.add_condition(
@@ -112,18 +114,39 @@ def initialize_service_template(service_name):
     service_tpl.add_condition(
         CREATE_PUBLIC_NAMESPACE_CON_T, CREATE_PUBLIC_NAMESPACE_CON
     )
+    service_tpl.add_condition(
+        ecs_conditions.CREATE_LOG_GROUP_CON_T, ecs_conditions.CREATE_LOG_GROUP_CON
+    )
+    service_tpl.add_condition(
+        ecs_conditions.GENERATED_LOG_GROUP_NAME_CON_T,
+        ecs_conditions.GENERATED_LOG_GROUP_NAME_CON,
+    )
+    return service_tpl
+
+
+def create_log_group(service_tpl, family):
+    """
+    Function to create a new Log Group for the services
+    :return:
+    """
     svc_log = service_tpl.add_resource(
         LogGroup(
             ecs_params.LOG_GROUP_T,
+            Condition=ecs_conditions.CREATE_LOG_GROUP_CON_T,
             RetentionInDays=Ref(ecs_params.LOG_GROUP_RETENTION),
-            LogGroupName=Sub(
-                f"svc/${{{ecs_params.CLUSTER_NAME_T}}}/${{{ecs_params.SERVICE_NAME_T}}}"
+            LogGroupName=If(
+                ecs_conditions.GENERATED_LOG_GROUP_NAME_CON_T,
+                Sub(
+                    f"${{{ROOT_STACK_NAME.title}}}/"
+                    f"svc/ecs/${{{ecs_params.CLUSTER_NAME_T}}}/${{{ecs_params.SERVICE_NAME_T}}}",
+                ),
+                Ref(ecs_params.LOG_GROUP_NAME),
             ),
         )
     )
     service_tpl.add_resource(
         PolicyType(
-            "CloudWatchAcccess",
+            "CloudWatchLogsAcccess",
             Roles=[Ref(ecs_params.EXEC_ROLE_T)],
             PolicyName=Sub(f"CloudWatchAccessFor${{{ecs_params.SERVICE_NAME_T}}}"),
             PolicyDocument={
@@ -132,14 +155,64 @@ def initialize_service_template(service_name):
                     {
                         "Sid": "AllowCloudWatchLoggingToSpecificLogGroup",
                         "Effect": "Allow",
-                        "Action": ["logs:CreateLogStream", "logs:PutLogEvents"],
-                        "Resource": [GetAtt(svc_log, "Arn")],
+                        "Action": [
+                            "logs:CreateLogStream",
+                            "logs:PutLogEvents",
+                            If(
+                                ecs_conditions.GENERATED_LOG_GROUP_NAME_CON_T,
+                                "logs:CreateLogGroup",
+                                Ref(AWS_NO_VALUE),
+                            ),
+                        ],
+                        "Resource": If(
+                            ecs_conditions.CREATE_LOG_GROUP_CON_T,
+                            [GetAtt(svc_log, "Arn")],
+                            If(
+                                ecs_conditions.GENERATED_LOG_GROUP_NAME_CON_T,
+                                [
+                                    Sub(
+                                        f"arn:${{{AWS_PARTITION}}}:logs:${{{AWS_REGION}}}:${{{AWS_ACCOUNT_ID}}}:"
+                                        f"log-group:${{{ROOT_STACK_NAME.title}}}/svc/ecs/"
+                                        f"${{{ecs_params.CLUSTER_NAME_T}}}/${{{ecs_params.SERVICE_NAME_T}}}:*"
+                                    ),
+                                    Sub(
+                                        f"arn:${{{AWS_PARTITION}}}:logs:${{{AWS_REGION}}}:${{{AWS_ACCOUNT_ID}}}:"
+                                        f"${{{ROOT_STACK_NAME.title}}}log-group:svc/ecs/"
+                                        f"${{{ecs_params.CLUSTER_NAME_T}}}/${{{ecs_params.SERVICE_NAME_T}}}"
+                                    ),
+                                ],
+                                [
+                                    Sub(
+                                        f"arn:${{{AWS_PARTITION}}}:logs:${{{AWS_REGION}}}:${{{AWS_ACCOUNT_ID}}}:"
+                                        f"log-group:${{{ecs_params.LOG_GROUP_NAME.title}}}:*"
+                                    ),
+                                    Sub(
+                                        f"arn:${{{AWS_PARTITION}}}:logs:${{{AWS_REGION}}}:${{{AWS_ACCOUNT_ID}}}:"
+                                        f"log-group:${{{ecs_params.LOG_GROUP_NAME.title}}}"
+                                    ),
+                                ],
+                            ),
+                        ),
                     },
                 ],
             },
         )
     )
-    return service_tpl
+    family.task_logging_options = {
+        "awslogs-group": If(
+            ecs_conditions.CREATE_LOG_GROUP_CON_T,
+            Ref(svc_log),
+            If(
+                ecs_conditions.GENERATED_LOG_GROUP_NAME_CON_T,
+                Sub(
+                    f"svc/ecs/${{{ecs_params.CLUSTER_NAME_T}}}/${{{ecs_params.SERVICE_NAME_T}}}",
+                ),
+                Ref(ecs_params.LOG_GROUP_NAME),
+            ),
+        ),
+        "awslogs-region": Ref(AWS_REGION),
+        "awslogs-create-group": True,
+    }
 
 
 def add_clusterwide_security_group(template):
@@ -162,86 +235,6 @@ def add_clusterwide_security_group(template):
     return sg
 
 
-def parse_string_labels(labels, svc_labels):
-    """
-    Function to format the label key value if labels are strings in a list
-
-    :param dict labels: labels dict to update with new labels
-    :param list svc_labels: the label string
-    """
-    for label in svc_labels:
-        if label.find("=") > 0:
-            splits = label.split("=")
-            labels.update({splits[0]: splits[1]})
-
-
-def update_families(families, labels, service_name):
-    """
-    Function to update families info from labels
-
-    :param dict families: registry of applications families
-    :param dict labels: the list of labels from a a service
-    :param str service_name: name of the service for which we get these labels
-    """
-    for label in labels:
-        if label == ECS_TASK_FAMILY_LABEL:
-            family_name = labels[label]
-            if not keyisset(family_name, families):
-                families[family_name] = [service_name]
-            elif keyisset(family_name, families):
-                families[family_name].append(service_name)
-
-
-def get_deploy_labels(service_definition):
-    """
-    Function to get the deploy labels of a service definition
-
-    :param dict service_definition: The service definition as defined in compose file
-    :return: labels if any
-    :rtype: dict
-    """
-    labels = {}
-    deploy_key = "deploy"
-    labels_key = "labels"
-    svc_labels = {}
-    if keyisset(deploy_key, service_definition) and keyisset(
-        labels_key, service_definition[deploy_key]
-    ):
-        svc_labels = service_definition[deploy_key][labels_key]
-        LOG.debug(f"labels: {svc_labels}")
-    if svc_labels:
-        if isinstance(svc_labels, list):
-            for item in svc_labels:
-                if not isinstance(item, str):
-                    raise TypeError(
-                        "When using a list for deploy labels, all labels must be of type string"
-                    )
-                parse_string_labels(labels, svc_labels)
-        elif isinstance(svc_labels, dict):
-            return svc_labels
-    return labels
-
-
-def define_services_families(services):
-    """
-    Function to group services together into a task family
-
-    :param dict services:
-    :return:
-    """
-    families = {}
-    for service_name in services:
-        labels = {}
-        service = services[service_name]
-        svc_labels = get_deploy_labels(service.definition)
-        LOG.debug(f"service {service_name} - labels {svc_labels}")
-        labels.update(svc_labels)
-        if not labels:
-            labels = {ECS_TASK_FAMILY_LABEL: service_name}
-        update_families(families, labels, service_name)
-    return families
-
-
 def get_service_family_name(services_families, service_name):
     """
     Function to return the root family name, representing the service stack name.
@@ -259,49 +252,38 @@ def get_service_family_name(services_families, service_name):
     return None
 
 
-def handle_families_services(families, cluster_sg, settings):
+def generate_services(settings):
     """
     Function to handle creation of services within the same family.
+
+    :param ecs_composex.common.settings.ComposeXSettings settings:
     :return:
     """
-    services = {}
-    for family_name in families:
-        family_resource_name = NONALPHANUM.sub("", family_name)
-        template = initialize_service_template(family_resource_name)
-        family = families[family_name]
-        family_service_configs = {}
-        family_parameters = {}
-        for service_name in family:
-            service = settings.compose_content[ecs_params.RES_KEY][service_name]
-            if keyisset("deploy", service.definition):
-                service.definition["deploy"].update(
-                    get_deploy_labels(service.definition)
-                )
-                LOG.debug(service.definition["deploy"])
-            service_config = ServiceConfig(
-                service,
-                settings.compose_content,
-                family_name=family_resource_name,
-            )
-            family_service_configs[service_name] = {
-                "config": service_config,
-                "priority": 0,
-                "definition": service,
-            }
-        task = Task(template, family_service_configs, family_parameters, settings)
-        family_parameters.update(task.stack_parameters)
-        service = Service(
-            template=template,
-            family_name=family_resource_name,
-            task_definition=task,
-            config=task.family_config,
-            settings=settings,
+    for family_name in settings.families:
+        family = settings.families[family_name]
+        family.template = initialize_service_template(family_name)
+        create_log_group(family.template, family)
+        if settings.secrets_mappings:
+            family.template.add_mapping(SECRETS_KEY, settings.secrets_mappings)
+        family.init_task_definition()
+        family.set_secrets_access()
+        family.refresh()
+        family.assign_policies()
+        family.service_config = ServiceConfig(family, settings)
+        family.ecs_service = Service(family, settings)
+        family.service_config.network.set_aws_sources(
+            family.logical_name, GetAtt(family.ecs_service.sg, "GroupId")
         )
-        service.parameters.update(
+        family.service_config.network.set_ext_sources_ingress(
+            family.logical_name, GetAtt(family.ecs_service.sg, "GroupId")
+        )
+        family.service_config.network.associate_aws_igress_rules(family.template)
+        family.service_config.network.associate_ext_igress_rules(family.template)
+        family.stack_parameters.update(
             {
+                ecs_params.SERVICE_NAME_T: family.logical_name,
                 CLUSTER_NAME_T: Ref(CLUSTER_NAME),
                 ROOT_STACK_NAME_T: Ref(ROOT_STACK_NAME),
-                ecs_params.CLUSTER_SG_ID_T: Ref(cluster_sg),
                 dns_params.PRIVATE_DNS_ZONE_ID.title: Ref(
                     dns_params.PRIVATE_DNS_ZONE_ID
                 ),
@@ -314,19 +296,3 @@ def handle_families_services(families, cluster_sg, settings):
                 ),
             }
         )
-        service.parameters.update(family_parameters)
-        LOG.debug(f"Service {family_resource_name} added.")
-        services[family_resource_name] = service
-    return services
-
-
-def generate_services(settings, cluster_sg):
-    """
-    Function putting together the ECS Service template
-
-    :param ComposeXSettings settings: The settings for execution
-    :param troposphere.ec2.SecurityGroup cluster_sg: cluster default security group
-    """
-    families = define_services_families(settings.compose_content[ecs_params.RES_KEY])
-    services = handle_families_services(families, cluster_sg, settings)
-    return services
