@@ -24,6 +24,8 @@ from importlib import import_module
 
 from troposphere import Ref, AWS_STACK_NAME, GetAtt
 
+from ecs_composex.acm.acm_params import RES_KEY as ACM_KEY
+from ecs_composex.acm.acm_stack import init_acm_certs
 from ecs_composex.appmesh.appmesh_mesh import Mesh
 from ecs_composex.common import LOG, NONALPHANUM
 from ecs_composex.common import (
@@ -47,15 +49,16 @@ from ecs_composex.compute.compute_params import (
 )
 from ecs_composex.compute.compute_stack import ComputeStack
 from ecs_composex.dns import add_parameters_and_conditions as dns_inputs, DnsSettings
-from ecs_composex.ecs import ServicesStack
-from ecs_composex.ecs import ecs_params
+from ecs_composex.dns.dns_records import DnsRecords
+from ecs_composex.ecs.ecs_stack import associate_services_to_root_stack
 from ecs_composex.ecs.ecs_cluster import add_ecs_cluster
 from ecs_composex.ecs.ecs_params import (
     CLUSTER_NAME,
     CLUSTER_T as ROOT_CLUSTER_NAME,
-    RES_KEY as SERVICES_KEY,
+    CREATE_CLUSTER,
+    FARGATE_VERSION,
 )
-from ecs_composex.ecs.ecs_template import define_services_families
+from ecs_composex.ecs.ecs_conditions import CREATE_CLUSTER_CON_T, CREATE_CLUSTER_CON
 from ecs_composex.vpc import vpc_params
 from ecs_composex.vpc.vpc_stack import add_vpc_to_root
 
@@ -64,28 +67,32 @@ COMPUTE_STACK_NAME = "Ec2Compute"
 VPC_STACK_NAME = "vpc"
 MESH_TITLE = "RootMesh"
 
-SUPPORTED_X_MODULES = [
-    f"{X_KEY}rds",
+SUPPORTED_X_MODULE_NAMES = [
     "rds",
-    f"{X_KEY}sqs",
     "sqs",
-    f"{X_KEY}sns",
     "sns",
-    f"{X_KEY}acm",
     "acm",
-    f"{X_KEY}dynamodb",
     "dynamodb",
-    f"{X_KEY}kms",
     "kms",
+    "s3",
+    "elbv2",
+    "docdb",
+    "events",
+    "kinesis",
 ]
+
+SUPPORTED_X_MODULES = [f"{X_KEY}{mod_name}" for mod_name in SUPPORTED_X_MODULE_NAMES]
 EXCLUDED_X_KEYS = [
     f"{X_KEY}configs",
     f"{X_KEY}tags",
     f"{X_KEY}appmesh",
+    f"{X_KEY}acm",
     f"{X_KEY}vpc",
     f"{X_KEY}dns",
     f"{X_KEY}cluster",
+    f"{X_KEY}efs",
 ]
+TCP_SERVICES = [f"{X_KEY}rds", f"{X_KEY}appmesh", f"{X_KEY}elbv2"]
 
 
 def get_mod_function(module_name, function_name):
@@ -142,40 +149,46 @@ def get_mod_class(module_name):
     return the_class
 
 
-def apply_x_configs_to_ecs(
-    settings, root_template, services_stack, services_families, **kwargs
-):
+def invoke_x_to_ecs(module, settings, services_stack, resource):
+    """
+    Function to associate X resources to Services
+
+    :param str module:
+    :param ecs_composex.common.settings.ComposeXSettings settings: The compose file content
+    :param ecs_composex.ecs.ServicesStack services_stack: root stack for services.
+    :param resource: The XStack resource
+    :return:
+    """
+    composex_key = f"{X_KEY}{module}"
+    ecs_function = get_mod_function(f"{module}.{module}_ecs", f"{module}_to_ecs")
+    if ecs_function:
+        LOG.debug(ecs_function)
+        ecs_function(
+            settings.compose_content[composex_key],
+            services_stack,
+            resource,
+            settings,
+        )
+
+
+def apply_x_configs_to_ecs(settings, root_stack):
     """
     Function that evaluates only the x- resources of the root template and iterates over the resources.
     If there is an implemented module in ECS ComposeX for that resource to map to the ECS Services, it will
     execute the function available in the module to apply defined settings to the services stack.
 
     :param ecs_composex.common.settings.ComposeXSettings settings: The compose file content
-    :param troposphere.Template root_template: The root template for ECS ComposeX
-    :param ecs_composex.ecs.ServicesStack services_stack: root stack for services.
-    :param dict kwargs: settings for building X related resources
-    :param dict services_families: Families and services mappings
+    :param ecs_composex.ecs.ServicesStack root_stack: root stack for services.
     """
-    for resource_name in root_template.resources:
-        resource = root_template.resources[resource_name]
+    for resource_name in root_stack.stack_template.resources:
+        resource = root_stack.stack_template.resources[resource_name]
         if (
             issubclass(type(resource), ComposeXStack)
-            and resource_name in SUPPORTED_X_MODULES
+            and resource_name in SUPPORTED_X_MODULE_NAMES
+            and not resource.is_void
         ):
             module = getattr(resource, "title")
-            composex_key = f"{X_KEY}{module}"
-            ecs_function = get_mod_function(
-                f"{module}.{module}_ecs", f"{module}_to_ecs"
-            )
-            if ecs_function:
-                LOG.debug(ecs_function)
-                ecs_function(
-                    settings.compose_content[composex_key],
-                    services_stack,
-                    services_families,
-                    resource,
-                    settings,
-                )
+            invoke_x_to_ecs(module, settings, root_stack, resource)
 
 
 def apply_x_to_x_configs(root_template, settings):
@@ -192,6 +205,7 @@ def apply_x_to_x_configs(root_template, settings):
             issubclass(type(resource), ComposeXStack)
             and resource_name in SUPPORTED_X_MODULES
             and hasattr(resource, "add_xdependencies")
+            and not resource.is_void
         ):
             resource.add_xdependencies(root_template, settings.compose_content)
 
@@ -227,11 +241,46 @@ def add_compute(root_template, settings, vpc_stack):
     return root_template.add_resource(compute_stack)
 
 
-def add_x_resources(root_template, settings, vpc_stack=None):
+def handle_new_xstack(
+    key,
+    res_type,
+    settings,
+    services_stack,
+    vpc_stack,
+    root_template,
+    xstack,
+):
+    """
+    Function to create the root stack of the x-resource and assign it to its root stack
+
+    :param str key:
+    :param str res_type:
+    :param ecs_composex.common.settings.ComposeXSettings settings:
+    :param ecs_composex.ecs.ServicesStack services_stack:
+    :param ecs_composex.common.stacks ComposeXStack vpc_stack:
+    :param troposphere.Template root_template:
+    :param ecs_composex.common.stacks ComposeXStack xstack:
+    """
+
+    LOG.debug(xstack, xstack.is_void)
+    if xstack.is_void:
+        invoke_x_to_ecs(res_type, settings, services_stack, xstack)
+    elif (
+        hasattr(xstack, "title")
+        and hasattr(xstack, "stack_template")
+        and not xstack.is_void
+    ):
+        root_template.add_resource(xstack)
+        if vpc_stack and key in TCP_SERVICES:
+            xstack.get_from_vpc_stack(vpc_stack)
+        elif not vpc_stack and key in TCP_SERVICES:
+            xstack.no_vpc_parameters()
+
+
+def add_x_resources(root_template, settings, services_stack, vpc_stack=None):
     """
     Function to add each X resource from the compose file
     """
-    tcp_services = ["x-rds", "x-appmesh"]
     for key in settings.compose_content:
         if key.startswith(X_KEY) and key not in EXCLUDED_X_KEYS:
             res_type = RES_REGX.sub("", key)
@@ -240,43 +289,22 @@ def add_x_resources(root_template, settings, vpc_stack=None):
             LOG.debug(xclass)
             if not xclass:
                 LOG.info(f"Class for {res_type} not found")
+                xstack = None
             else:
                 xstack = xclass(
                     res_type.strip(),
                     settings=settings,
                     Parameters=parameters,
                 )
-                if vpc_stack and key in tcp_services:
-                    xstack.get_from_vpc_stack(vpc_stack)
-                elif not vpc_stack and key in tcp_services:
-                    xstack.no_vpc_parameters()
-                root_template.add_resource(xstack)
-
-
-def create_services(root_stack, settings, vpc_stack, dns_params, create_cluster):
-    """
-    Function to add the microservices root stack
-
-    :param ComposeXStack root_stack: ComposeX root stack
-    :param ComposeXSettings settings: The settings for execution
-    :param ComposeXStack vpc_stack: The VPC Stack
-    :param dict dns_params: DNS Parameters for the execution
-    :param bool create_cluster: Indicates whether the cluster is created from this stack
-    """
-    stack = ServicesStack("services", settings)
-    stack.Parameters.update(
-        {
-            ecs_params.CLUSTER_NAME_T: Ref(CLUSTER_NAME)
-            if not create_cluster
-            else Ref(ROOT_CLUSTER_NAME)
-        }
-    )
-    stack.Parameters.update(dns_params)
-    if vpc_stack:
-        stack.get_from_vpc_stack(vpc_stack)
-    if create_cluster:
-        stack.DependsOn.append(ROOT_CLUSTER_NAME)
-    return root_stack.stack_template.add_resource(stack)
+            handle_new_xstack(
+                key,
+                res_type,
+                settings,
+                services_stack,
+                vpc_stack,
+                root_template,
+                xstack,
+            )
 
 
 def get_vpc_id(vpc_stack):
@@ -301,8 +329,9 @@ def init_root_template():
 
     template = build_template(
         "Root template generated via ECS ComposeX",
-        [USE_FLEET, USE_ONDEMAND, CLUSTER_NAME],
+        [USE_FLEET, USE_ONDEMAND, CLUSTER_NAME, CREATE_CLUSTER, FARGATE_VERSION],
     )
+    template.add_condition(CREATE_CLUSTER_CON_T, CREATE_CLUSTER_CON)
     return template
 
 
@@ -321,29 +350,33 @@ def generate_full_template(settings):
     )
     dns_inputs(root_stack)
     vpc_stack = add_vpc_to_root(root_stack, settings)
+    settings.set_networks(vpc_stack, root_stack)
     dns_settings = DnsSettings(root_stack, settings, get_vpc_id(vpc_stack))
     root_stack.Parameters.update(dns_settings.root_params)
-    create_cluster = add_ecs_cluster(settings, root_stack)
+    add_ecs_cluster(settings, root_stack)
     compute_stack = add_compute(root_stack.stack_template, settings, vpc_stack)
-    if create_cluster and settings.create_compute and compute_stack:
+    if settings.create_compute and compute_stack:
         compute_stack.DependsOn.append(ROOT_CLUSTER_NAME)
-    services_families = define_services_families(settings.compose_content[SERVICES_KEY])
-    services_stack = create_services(
-        root_stack, settings, vpc_stack, dns_settings.nested_params, create_cluster
+    associate_services_to_root_stack(
+        root_stack, settings, dns_settings.nested_params, vpc_stack
+    )
+    if keyisset(ACM_KEY, settings.compose_content):
+        init_acm_certs(settings, dns_settings, root_stack)
+    add_x_resources(
+        root_stack.stack_template,
+        settings,
+        root_stack,
+        vpc_stack=vpc_stack,
     )
-    add_x_resources(root_stack.stack_template, settings, vpc_stack=vpc_stack)
     apply_x_configs_to_ecs(
-        settings, root_stack.stack_template, services_stack, services_families
+        settings,
+        root_stack,
     )
     apply_x_to_x_configs(root_stack.stack_template, settings)
-
     if keyisset("x-appmesh", settings.compose_content):
-        mesh = Mesh(
-            settings.compose_content["x-appmesh"],
-            services_families,
-            services_stack,
-            settings,
-        )
-        mesh.render_mesh_template(services_stack)
+        mesh = Mesh(settings.compose_content["x-appmesh"], root_stack, settings)
+        mesh.render_mesh_template(root_stack)
+    dns_records = DnsRecords(settings)
+    dns_records.associate_records_to_resources(settings, root_stack, dns_settings)
     add_all_tags(root_stack.stack_template, settings)
     return root_stack
