@@ -15,16 +15,21 @@
 #   You should have received a copy of the GNU General Public License
 #   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from troposphere import Ref, Sub, If, AWS_PARTITION, AWS_ACCOUNT_ID
+from troposphere import Ref, Sub, If, GetAtt
+from troposphere import AWS_PARTITION, AWS_ACCOUNT_ID
 from troposphere.kms import Key, Alias
+
+from ecs_composex.resources_import import import_record_properties
 from ecs_composex.common import keyisset, LOG
 from ecs_composex.common.cfn_params import ROOT_STACK_NAME
 from ecs_composex.common.cfn_conditions import USE_STACK_NAME_CON_T
 from ecs_composex.common.stacks import ComposeXStack
 from ecs_composex.common.compose_resources import set_resources, XResource
+
 from ecs_composex.kms import metadata
 from ecs_composex.kms.kms_template import create_kms_template
-from ecs_composex.kms.kms_params import RES_KEY
+from ecs_composex.kms.kms_params import RES_KEY, KMS_KEY_ARN, KMS_KEY_ID
+from ecs_composex.kms.kms_perms import get_access_types
 
 
 def define_default_key_policy():
@@ -61,15 +66,33 @@ class KmsKey(XResource):
     Class to represent a KMS Key
     """
 
-    def __init__(self, name, definition):
-        super().__init__(name, definition)
+    policies_scaffolds = get_access_types()
+
+    def __init__(self, name, definition, settings):
+        super().__init__(name, definition, settings)
+        self.arn_attr = KMS_KEY_ARN
+        self.main_attr = KMS_KEY_ID
+        self.kms_arn_attr = None
+        self.arn_attr_value = self.arn_attr
+        self.main_attr_value = self.main_attr
+
+    def init_outputs(self):
+        self.output_properties = {
+            KMS_KEY_ID.title: (self.logical_name, self.cfn_resource, Ref, None),
+            KMS_KEY_ARN.title: (
+                f"{self.logical_name}{KMS_KEY_ARN.title}",
+                self.cfn_resource,
+                GetAtt,
+                KMS_KEY_ARN.title,
+            ),
+        }
 
     def define_kms_key(self):
         """
         Method to set the KMS Key
         """
         if not self.properties:
-            self.properties = {
+            props = {
                 "Description": Sub(
                     f"{self.name} created in ${{{ROOT_STACK_NAME.title}}}"
                 ),
@@ -78,11 +101,13 @@ class KmsKey(XResource):
                 "KeyUsage": "ENCRYPT_DECRYPT",
                 "PendingWindowInDays": 7,
             }
-        if not keyisset("KeyPolicy", self.properties):
-            self.properties.update({"KeyPolicy": define_default_key_policy()})
-        self.properties.update({"Metadata": metadata})
-        LOG.debug(self.properties)
-        self.cfn_resource = Key(self.logical_name, **self.properties)
+        else:
+            props = import_record_properties(self.properties, Key)
+        if not keyisset("KeyPolicy", props):
+            props.update({"KeyPolicy": define_default_key_policy()})
+        props.update({"Metadata": metadata})
+        LOG.debug(props)
+        self.cfn_resource = Key(self.logical_name, **props)
 
     def handle_key_settings(self, template):
         """
