@@ -16,18 +16,15 @@
 #   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
-from troposphere import Ref, GetAtt
+from troposphere import MAX_OUTPUTS
 
 from ecs_composex.common import keyisset, build_template
-from ecs_composex.common.outputs import ComposeXOutput
 from ecs_composex.common.stacks import ComposeXStack
 from ecs_composex.kms.kms_params import (
     RES_KEY,
-    KMS_KEY_ID_T,
-    KMS_KEY_ARN_T,
 )
 
-CFN_MAX_OUTPUTS = 50
+CFN_MAX_OUTPUTS = MAX_OUTPUTS - 10
 
 
 def create_kms_template(settings):
@@ -40,30 +37,27 @@ def create_kms_template(settings):
     template = build_template("Root template for KMS")
     if not keyisset(RES_KEY, settings.compose_content):
         return
-    keys = settings.compose_content[RES_KEY]
-    if len(list(keys.keys())) <= CFN_MAX_OUTPUTS:
+    x_keys = settings.compose_content[RES_KEY]
+    new_keys = [x_keys[key_name] for key_name in x_keys if not x_keys[key_name].lookup]
+    if len(new_keys) <= CFN_MAX_OUTPUTS:
         mono_template = True
 
-    for key_name in keys:
-        key = keys[key_name]
+    for key in new_keys:
         key.define_kms_key()
-        if key:
-            values = [
-                (KMS_KEY_ARN_T, "Arn", GetAtt(key.cfn_resource, "Arn")),
-                (KMS_KEY_ID_T, "Name", Ref(key.cfn_resource)),
-            ]
-            outputs = ComposeXOutput(key.cfn_resource, values, True)
+        if key and key.cfn_resource:
+            key.init_outputs()
+            key.generate_outputs()
             if mono_template:
                 template.add_resource(key.cfn_resource)
                 key.handle_key_settings(template)
-                template.add_output(outputs.outputs)
+                template.add_output(key.outputs)
             elif not mono_template:
                 key_template = build_template(
                     f"Template for KMS key {key.logical_name}"
                 )
                 key_template.add_resource(key.cfn_resource)
                 key.handle_key_settings(key_template)
-                key_template.add_output(outputs.outputs)
+                key_template.add_output(key.outputs)
                 key_stack = ComposeXStack(key.logical_name, stack_template=key_template)
                 template.add_resource(key_stack)
     return template
