@@ -19,7 +19,7 @@
 RDS DB template generator
 """
 
-from troposphere import Sub, Ref, If, GetAtt, Tags, AWS_NO_VALUE
+from troposphere import Sub, Ref, GetAtt, If, Tags, AWS_NO_VALUE
 from troposphere.ec2 import SecurityGroup
 from troposphere.rds import (
     DBSubnetGroup,
@@ -28,70 +28,53 @@ from troposphere.rds import (
     DBInstance,
     DBParameterGroup,
 )
-from troposphere.secretsmanager import (
-    Secret,
-    SecretTargetAttachment,
-    GenerateSecretString,
-)
 
 from ecs_composex.common import build_template, cfn_conditions
 from ecs_composex.common.cfn_params import ROOT_STACK_NAME_T
-from ecs_composex.common.outputs import ComposeXOutput
 from ecs_composex.rds import rds_conditions
 from ecs_composex.rds.rds_parameter_groups_helper import (
     get_family_from_engine_version,
     get_family_settings,
 )
+from ecs_composex.rds.rds_params import (
+    CLUSTER_SUBNET_GROUP,
+    CLUSTER_T,
+    DATABASE_T,
+    PARAMETER_GROUP_T,
+    CLUSTER_PARAMETER_GROUP_T,
+)
 from ecs_composex.rds.rds_params import (
     DB_ENGINE_VERSION,
     DB_ENGINE_NAME,
     DBS_SUBNET_GROUP,
-    DB_SG_T,
     DB_NAME,
-    DB_NAME_T,
     DB_SNAPSHOT_ID,
     DB_INSTANCE_CLASS,
     DB_PASSWORD_LENGTH,
-    DB_USERNAME_T,
     DB_USERNAME,
     DB_STORAGE_CAPACITY,
     DB_STORAGE_TYPE,
-    DB_EXPORT_SECRET_ARN_T,
-    DB_EXPORT_PORT_T,
-    DB_EXPORT_SG_ID_T,
+)
+from ecs_composex.secrets import (
+    add_db_secret,
+    add_db_dependency,
+    attach_to_secret_to_resource,
 )
 from ecs_composex.vpc.vpc_params import (
     VPC_ID,
     STORAGE_SUBNETS,
 )
 
-CLUSTER_SUBNET_GROUP = "ClusterSubnetGroup"
-DB_SECRET_T = "RdsDbSecret"
-CLUSTER_T = "AuroraCluster"
-DATABASE_T = "RdsDatabase"
-PARAMETER_GROUP_T = "RdsParametersGroup"
-CLUSTER_PARAMETER_GROUP_T = "RdsClusterParameterGroup"
 
-
-def add_db_outputs(db_template, db_name):
+def add_db_outputs(db_template, db):
     """
     Function to add outputs to the DB template
 
     :param db_template: DB Template
     :type db_template: troposphere.Template
-    :param str db_name: Name of the database
     """
-    db_template.add_output(
-        ComposeXOutput(
-            db_name,
-            [
-                (DB_EXPORT_SECRET_ARN_T, "SecretArn", Ref(DB_SECRET_T)),
-                (DB_EXPORT_PORT_T, "Port", GetAtt(CLUSTER_T, "Endpoint.Port")),
-                (DB_NAME_T, "DbName", Ref(DATABASE_T)),
-                (DB_EXPORT_SG_ID_T, "GroupId", GetAtt(DB_SG_T, "GroupId")),
-            ],
-        ).outputs
-    )
+    db.generate_outputs()
+    db_template.add_output(db.outputs)
 
 
 def create_db_subnet_group(template, conditional=False):
@@ -130,8 +113,8 @@ def add_db_sg(template, db_name):
     :param str db_name: Name of the database as defined in compose file
     :param troposphere.Template template: template to add the sg to
     """
-    SecurityGroup(
-        DB_SG_T,
+    return SecurityGroup(
+        f"{db_name}Sg",
         template=template,
         GroupName=Sub(f"${{{ROOT_STACK_NAME_T}}}-{db_name}"),
         GroupDescription=Sub(f"${{{ROOT_STACK_NAME_T}}} ${db_name}"),
@@ -139,53 +122,14 @@ def add_db_sg(template, db_name):
     )
 
 
-def add_db_secret(template):
-    """
-    Function to add a Secrets Manager secret that will be associated with the DB
-    :param template.Template template: The template to add the secret to.
-    """
-    Secret(
-        DB_SECRET_T,
-        template=template,
-        GenerateSecretString=GenerateSecretString(
-            SecretStringTemplate=Sub(f'{{"username":"${{{DB_USERNAME_T}}}"}}'),
-            GenerateStringKey="password",
-            ExcludeCharacters="<>%`|;,.",
-            ExcludePunctuation=True,
-            ExcludeLowercase=False,
-            ExcludeUppercase=False,
-            IncludeSpace=False,
-            RequireEachIncludedType=True,
-            PasswordLength=Ref(DB_PASSWORD_LENGTH),
-        ),
-    )
-    SecretTargetAttachment(
-        "ClusterRdsSecretAttachment",
-        template=template,
-        Condition=rds_conditions.USE_CLUSTER_CON_T,
-        DependsOn=[DB_SECRET_T, CLUSTER_T],
-        TargetType=DBCluster.resource_type,
-        SecretId=Ref(DB_SECRET_T),
-        TargetId=Ref(CLUSTER_T),
-    )
-    SecretTargetAttachment(
-        "DatabaseRdsSecretAttachment",
-        template=template,
-        Condition=rds_conditions.NOT_USE_CLUSTER_CON_T,
-        DependsOn=[DB_SECRET_T, DATABASE_T],
-        TargetType=DBInstance.resource_type,
-        SecretId=Ref(DB_SECRET_T),
-        TargetId=Ref(DATABASE_T),
-    )
-
-
-def add_instance(template):
+def add_instance(template, db):
     """
     Function to add DB Instance(s)
 
     :param troposphere.Template template: The template to add the DB Instance to.
+    :param db:
     """
-    DBInstance(
+    instance = DBInstance(
         DATABASE_T,
         template=template,
         Engine=Ref(DB_ENGINE_NAME),
@@ -212,7 +156,7 @@ def add_instance(template):
             rds_conditions.USE_CLUSTER_OR_SNAPSHOT_CON_T,
             Ref(AWS_NO_VALUE),
             Sub(
-                f"{{{{resolve:secretsmanager:${{{DB_SECRET_T}}}:SecretString:username}}}}"
+                f"{{{{resolve:secretsmanager:${{{db.db_secret.title}}}:SecretString:username}}}}"
             ),
         ),
         DBClusterIdentifier=If(
@@ -222,17 +166,21 @@ def add_instance(template):
             rds_conditions.USE_CLUSTER_CON_T,
             Ref(AWS_NO_VALUE),
             Sub(
-                f"{{{{resolve:secretsmanager:${{{DB_SECRET_T}}}:SecretString:password}}}}"
+                f"{{{{resolve:secretsmanager:${{{db.db_secret.title}}}:SecretString:password}}}}"
             ),
         ),
         VPCSecurityGroups=If(
-            rds_conditions.USE_CLUSTER_CON_T, Ref(AWS_NO_VALUE), [Ref(DB_SG_T)]
+            rds_conditions.USE_CLUSTER_CON_T,
+            Ref(AWS_NO_VALUE),
+            [GetAtt(db.db_sg, "GroupId")],
         ),
-        Tags=Tags(SecretName=Ref(DB_SECRET_T)),
+        Tags=Tags(SecretName=Ref(db.db_secret), Name=db.logical_name),
+        StorageEncrypted=True,
     )
+    return instance
 
 
-def add_cluster(template):
+def add_cluster(template, db):
     """
     Function to add the cluster to the template
 
@@ -254,11 +202,11 @@ def add_cluster(template):
             rds_conditions.USE_CLUSTER_AND_SNAPSHOT_CON_T,
             Ref(AWS_NO_VALUE),
             Sub(
-                f"{{{{resolve:secretsmanager:${{{DB_SECRET_T}}}:SecretString:username}}}}"
+                f"{{{{resolve:secretsmanager:${{{db.db_secret.title}}}:SecretString:username}}}}"
             ),
         ),
         MasterUserPassword=Sub(
-            f"{{{{resolve:secretsmanager:${{{DB_SECRET_T}}}:SecretString:password}}}}"
+            f"{{{{resolve:secretsmanager:${{{db.db_secret.title}}}:SecretString:password}}}}"
         ),
         SnapshotIdentifier=If(
             rds_conditions.USE_CLUSTER_CON_T,
@@ -272,8 +220,9 @@ def add_cluster(template):
         Engine=Ref(DB_ENGINE_NAME),
         EngineVersion=Ref(DB_ENGINE_VERSION),
         DBClusterParameterGroupName=Ref(CLUSTER_PARAMETER_GROUP_T),
-        VpcSecurityGroupIds=[Ref(DB_SG_T)],
-        Tags=Tags(SecretName=Ref(DB_SECRET_T)),
+        VpcSecurityGroupIds=[Ref(db.db_sg)],
+        Tags=Tags(SecretName=Ref(db.db_secret), Name=db.logical_name),
+        StorageEncrypted=True,
     )
     return cluster
 
@@ -377,16 +326,24 @@ def init_database_template(db_name):
 def generate_database_template(db):
     """
     Function to generate the database template
-    :param ecs_composex.common.compose_resources.Rds db: The database object
+    :param ecs_composex.rds.rds_stack.Rds db: The database object
 
     :return: db_template
     :rtype: troposphere.Template
     """
     db_template = init_database_template(db.name)
-    add_cluster(db_template)
-    add_db_secret(db_template)
-    add_db_sg(db_template, db.logical_name)
-    add_instance(db_template)
+    db.db_secret = add_db_secret(db_template, db.logical_name)
+    db.db_sg = add_db_sg(db_template, db.logical_name)
+    instance = add_instance(db_template, db)
+    cluster = add_cluster(db_template, db)
     add_parameter_group(db_template, db)
-    add_db_outputs(db_template, db.logical_name)
+    if db.properties[DB_ENGINE_NAME.title].startswith("aurora"):
+        db.cfn_resource = cluster
+    else:
+        db.cfn_resource = instance
+    add_db_dependency(db.cfn_resource, db.db_secret)
+    attach_to_secret_to_resource(db_template, db.cfn_resource, db.db_secret)
+    db.init_outputs()
+    add_db_outputs(db_template, db)
+    db.is_nested = True
     return db_template
