@@ -20,18 +20,25 @@ Module to handle AWS RDS CFN Templates creation
 """
 
 import os
-from warnings import warn
 
-from ecs_composex.common import LOG, keyisset
-from ecs_composex.rds.rds_template import generate_rds_templates
-from ecs_composex.common.stacks import ComposeXStack
+from troposphere import Parameter
+from troposphere import Ref, GetAtt
+
+from ecs_composex.common import LOG
 from ecs_composex.common.compose_resources import XResource, set_resources
+from ecs_composex.common.stacks import ComposeXStack
+from ecs_composex.rds.rds_params import (
+    DB_NAME,
+    DB_ENDPOINT_PORT,
+    DB_SECRET_T,
+)
+from ecs_composex.rds.rds_template import generate_rds_templates
 
 RES_KEY = f"x-{os.path.basename(os.path.dirname(os.path.abspath(__file__)))}"
 RDS_SSM_PREFIX = f"/{RES_KEY}/"
 
 
-def create_rds_template(settings):
+def create_rds_template(settings, new_dbs):
     """
     Creates the CFN Troposphere template
 
@@ -41,10 +48,7 @@ def create_rds_template(settings):
     :return: rds_tpl
     :rtype: troposphere.Template
     """
-    if not keyisset(RES_KEY, settings.compose_content):
-        warn(f"No {RES_KEY} found in the docker compose definition. Skipping")
-        return None
-    rds_tpl = generate_rds_templates(settings)
+    rds_tpl = generate_rds_templates(new_dbs)
     LOG.debug(f"Template for {RES_KEY} validated by CFN.")
     return rds_tpl
 
@@ -54,8 +58,37 @@ class Rds(XResource):
     Class to represent a RDS DB
     """
 
-    def __init__(self, name, definition):
-        super().__init__(name, definition)
+    def __init__(self, name, definition, settings):
+        self.db_secret = None
+        self.db_sg = None
+        super().__init__(name, definition, settings)
+        self.arn_attr = Parameter(DB_SECRET_T, Type="String")
+
+    def init_outputs(self):
+        """
+        Method to init the RDS Output attributes
+        """
+        self.output_properties = {
+            DB_NAME.title: (self.logical_name, self.cfn_resource, Ref, None),
+            DB_ENDPOINT_PORT: (
+                f"{self.logical_name}{DB_ENDPOINT_PORT}",
+                self.cfn_resource,
+                GetAtt,
+                DB_ENDPOINT_PORT,
+            ),
+            self.db_secret.title: (
+                self.db_secret.title,
+                self.db_secret,
+                Ref,
+                None,
+            ),
+            self.db_sg.title: (
+                self.db_sg.title,
+                self.db_sg,
+                GetAtt,
+                "GroupId",
+            ),
+        }
 
 
 class XStack(ComposeXStack):
@@ -65,5 +98,13 @@ class XStack(ComposeXStack):
 
     def __init__(self, title, settings, **kwargs):
         set_resources(settings, Rds, RES_KEY)
-        template = create_rds_template(settings)
-        super().__init__(title, stack_template=template, **kwargs)
+        new_dbs = [
+            settings.compose_content[RES_KEY][db_name]
+            for db_name in settings.compose_content[RES_KEY]
+            if not settings.compose_content[RES_KEY][db_name].lookup
+        ]
+        if new_dbs:
+            template = create_rds_template(settings, new_dbs)
+            super().__init__(title, stack_template=template, **kwargs)
+        else:
+            self.is_void = True
