@@ -19,9 +19,10 @@
 Main module template to generate the RDS Root template and all stacks according to x-rds settings
 """
 
-from troposphere import Ref, Join
+from troposphere import Output
+from troposphere import Ref, Join, GetAtt
 
-from ecs_composex.common import build_template, validate_kwargs
+from ecs_composex.common import build_template, validate_kwargs, keyisset
 from ecs_composex.common.cfn_params import ROOT_STACK_NAME_T, ROOT_STACK_NAME
 from ecs_composex.common.stacks import ComposeXStack
 from ecs_composex.rds.rds_db_template import (
@@ -29,11 +30,11 @@ from ecs_composex.rds.rds_db_template import (
     create_db_subnet_group,
 )
 from ecs_composex.rds.rds_params import (
-    RES_KEY,
     DBS_SUBNET_GROUP_T,
     DB_NAME_T,
     DB_ENGINE_VERSION_T,
     DB_ENGINE_NAME_T,
+    DB_SNAPSHOT_ID,
 )
 from ecs_composex.vpc.vpc_params import (
     VPC_ID,
@@ -43,7 +44,7 @@ from ecs_composex.vpc.vpc_params import (
 )
 
 
-def add_db_stack(root_template, dbs_subnet_group, db, settings):
+def add_db_stack(root_template, dbs_subnet_group, db):
     """
     Function to add the DB stack to the root stack
 
@@ -54,12 +55,15 @@ def add_db_stack(root_template, dbs_subnet_group, db, settings):
     :param db: the database definition from the compose file
     :type db: ecs_composex.common.compose_resources.Rds
     """
-    props = db.properties
+    if not db.properties and not db.parameters:
+        raise RuntimeError(
+            f"No Properties nor MacroParameters defined for {db.logical_name}"
+        )
     required_props = [DB_ENGINE_NAME_T, DB_ENGINE_VERSION_T]
-    validate_kwargs(required_props, props)
+    validate_kwargs(required_props, db.properties)
     non_stack_params = {
-        DB_ENGINE_NAME_T: props[DB_ENGINE_NAME_T],
-        DB_ENGINE_VERSION_T: props[DB_ENGINE_VERSION_T],
+        DB_ENGINE_NAME_T: db.properties[DB_ENGINE_NAME_T],
+        DB_ENGINE_VERSION_T: db.properties[DB_ENGINE_VERSION_T],
     }
     parameters = {
         VPC_ID_T: Ref(VPC_ID),
@@ -68,6 +72,10 @@ def add_db_stack(root_template, dbs_subnet_group, db, settings):
         STORAGE_SUBNETS_T: Join(",", Ref(STORAGE_SUBNETS)),
         ROOT_STACK_NAME_T: Ref(ROOT_STACK_NAME),
     }
+    if keyisset("SnapshotIdentifier", db.properties):
+        parameters.update({DB_SNAPSHOT_ID.title: db.properties["SnapshotIdentifier"]})
+    elif keyisset("DBSnapshotIdentifier", db.properties):
+        parameters.update({DB_SNAPSHOT_ID.title: db.properties["DBSnapshotIdentifier"]})
     parameters.update(non_stack_params)
     db_template = generate_database_template(db)
     if db_template is None:
@@ -76,6 +84,12 @@ def add_db_stack(root_template, dbs_subnet_group, db, settings):
         db.logical_name, stack_template=db_template, stack_parameters=parameters
     )
     root_template.add_resource(db_stack)
+    new_outputs = []
+    for output_name in db_stack.stack_template.outputs:
+        new_outputs.append(
+            Output(output_name, Value=GetAtt(db.logical_name, f"Outputs.{output_name}"))
+        )
+    root_template.add_output(new_outputs)
 
 
 def init_rds_root_template():
@@ -89,23 +103,16 @@ def init_rds_root_template():
     return template
 
 
-def generate_rds_templates(settings):
+def generate_rds_templates(new_dbs):
     """
     Function to generate the RDS root template for all the DBs defined in the x-rds section of the compose file
 
-    :param ecs_composex.common.settings.ComposeXSettings settings: Settings for execution
-
+    :param list new_dbs:
     :return: rds_root_template, the RDS Root template with nested stacks
     :rtype: troposphere.Template
     """
     root_tpl = init_rds_root_template()
     dbs_subnet_group = create_db_subnet_group(root_tpl)
-    section = settings.compose_content[RES_KEY]
-    for db_name in section:
-        add_db_stack(
-            root_tpl,
-            dbs_subnet_group,
-            section[db_name],
-            settings,
-        )
+    for db in new_dbs:
+        add_db_stack(root_tpl, dbs_subnet_group, db)
     return root_tpl
