@@ -15,12 +15,15 @@
 #   You should have received a copy of the GNU General Public License
 #   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+from troposphere import GetAtt, Ref
+
 from ecs_composex.common import keyisset, LOG
-from ecs_composex.sns.sns_params import RES_KEY
+from ecs_composex.common.compose_resources import XResource
+from ecs_composex.common.stacks import ComposeXStack
+from ecs_composex.sns.sns_params import RES_KEY, TOPIC_NAME, TOPIC_ARN, TOPIC_KMS_KEY
+from ecs_composex.sns.sns_perms import ACCESS_TYPES
 from ecs_composex.sns.sns_templates import generate_sns_templates
 from ecs_composex.sqs.sqs_params import RES_KEY as SQS_KEY
-from ecs_composex.common.stacks import ComposeXStack
-from ecs_composex.common.compose_resources import XResource
 
 
 def create_sns_template(settings):
@@ -42,8 +45,30 @@ class Topic(XResource):
     Class for SNS Topics
     """
 
+    policies_scaffolds = ACCESS_TYPES
     keyword = "Topics"
 
+    def __init__(self, name, definition, settings):
+        super().__init__(name, definition, settings)
+        self.arn_attr = TOPIC_ARN
+        self.main_attr = TOPIC_NAME
+        self.kms_attr = TOPIC_KMS_KEY
+        self.arn_attr_value = self.arn_attr
+        self.main_attr_value = self.main_attr
+        self.kms_attr_value = self.kms_attr
+
+    def init_outputs(self):
+        self.output_properties = {
+            TOPIC_ARN.title: (self.logical_name, self.cfn_resource, Ref, None),
+            TOPIC_NAME.title: (
+                f"{self.logical_name}{TOPIC_NAME.title}",
+                self.cfn_resource,
+                GetAtt,
+                TOPIC_NAME.title,
+            ),
+            self.arn_attr.title: (self.logical_name, self.cfn_resource, Ref, None),
+        }
+
 
 class Subscription(XResource):
     """
@@ -64,6 +89,7 @@ class XStack(ComposeXStack):
                 settings.compose_content[RES_KEY][Topic.keyword][resource_name] = Topic(
                     resource_name,
                     settings.compose_content[RES_KEY][Topic.keyword][resource_name],
+                    settings,
                 )
 
         if keyisset(Subscription.keyword, settings.compose_content[RES_KEY]):
@@ -77,6 +103,7 @@ class XStack(ComposeXStack):
                     settings.compose_content[RES_KEY][Subscription.keyword][
                         resource_name
                     ],
+                    settings,
                 )
 
         template = create_sns_template(settings)
