@@ -35,5 +35,9 @@ DLQ_NAME = Parameter(DLQ_NAME_T, Type="String")
 DLQ_ARN_T = "DeadLetterQueueArn"
 DLQ_ARN = Parameter(DLQ_ARN_T, Type="String")
 
-RES_KEY = f"x-{path.basename(path.dirname(path.abspath(__file__)))}"
+SQS_KMS_KEY_T = "QueueKmsKey"
+SQS_KMS_KEY = Parameter(SQS_KMS_KEY_T, Type="String")
+
+MOD_KEY = f"{path.basename(path.dirname(path.abspath(__file__)))}"
+RES_KEY = f"x-{MOD_KEY}"
 SQS_SSM_PREFIX = f"/{RES_KEY}/"
