@@ -20,11 +20,21 @@ Module for the XStack SQS
 """
 
 import sys
+
+from troposphere import GetAtt, Ref
+
 from ecs_composex.common import validate_input, keyisset, LOG, EXIT_CODES
-from ecs_composex.sqs.sqs_params import RES_KEY
-from ecs_composex.sqs.sqs_template import generate_sqs_root_template
-from ecs_composex.common.stacks import ComposeXStack
 from ecs_composex.common.compose_resources import set_resources, XResource
+from ecs_composex.common.stacks import ComposeXStack
+from ecs_composex.sqs.sqs_params import (
+    RES_KEY,
+    SQS_ARN,
+    SQS_URL,
+    SQS_KMS_KEY,
+    SQS_NAME,
+)
+from ecs_composex.sqs.sqs_perms import get_access_types
+from ecs_composex.sqs.sqs_template import generate_sqs_root_template
 
 
 def create_sqs_template(settings):
@@ -51,8 +61,30 @@ class Queue(XResource):
     Class to represent a SQS Queue
     """
 
-    def __init__(self, name, definition):
-        super().__init__(name, definition)
+    policies_scaffolds = get_access_types()
+
+    def __init__(self, name, definition, settings):
+        super().__init__(name, definition, settings)
+        self.main_attr = SQS_URL
+        self.kms_arn_attr = SQS_KMS_KEY
+        self.arn_attr = SQS_ARN
+
+    def init_outputs(self):
+        self.output_properties = {
+            SQS_URL.title: (self.logical_name, self.cfn_resource, Ref, None),
+            SQS_ARN.title: (
+                f"{self.logical_name}{SQS_ARN.title}",
+                self.cfn_resource,
+                GetAtt,
+                SQS_ARN.title,
+            ),
+            SQS_NAME.title: (
+                f"{self.logical_name}{SQS_NAME.title}",
+                self.cfn_resource,
+                GetAtt,
+                SQS_NAME.title,
+            ),
+        }
 
 
 class XStack(ComposeXStack):
