@@ -30,23 +30,19 @@ from ecs_composex.common import (
     NONALPHANUM,
 )
 from ecs_composex.common.cfn_params import ROOT_STACK_NAME_T
-from ecs_composex.common.outputs import ComposeXOutput
 from ecs_composex.common.stacks import ComposeXStack
 from ecs_composex.sqs import metadata
 from ecs_composex.sqs.sqs_params import RES_KEY
 from ecs_composex.sqs.sqs_params import (
-    SQS_NAME_T,
     SQS_ARN_T,
     DLQ_ARN,
     DLQ_ARN_T,
-    SQS_URL,
 )
 
-CFN_MAX_OUTPUTS = 50
+CFN_MAX_OUTPUTS = 190
 
 
 def define_redrive_policy(target_queue, retries=None, mono_template=True):
-
     policy = {
         "RedrivePolicy": RedrivePolicy(
             deadLetterTargetArn=GetAtt(target_queue, "Arn")
@@ -69,13 +65,24 @@ def set_queue(queue, properties, redrive_policy=None):
     :return: queue
     :rtype: troposphere.sqs.Queue
     """
+    name = None
     if redrive_policy is not None:
         properties.update(redrive_policy)
     if keyisset("QueueName", properties):
+        name = properties["QueueName"]
         properties.pop("QueueName")
-        properties["QueueName"] = Sub(f"${{{ROOT_STACK_NAME_T}}}-{queue.name}")
-        if keyisset("FifoQueue", properties):
-            properties["QueueName"] = Sub(f"${{{ROOT_STACK_NAME_T}}}-{queue.name}.fifo")
+    if keyisset("FifoQueue", properties):
+        properties["QueueName"] = (
+            Sub(f"${{{ROOT_STACK_NAME_T}}}-{queue.name}.fifo")
+            if not name
+            else Sub(f"${{{ROOT_STACK_NAME_T}}}-{name}.fifo")
+        )
+    else:
+        properties["QueueName"] = (
+            Sub(f"${{{ROOT_STACK_NAME_T}}}-{queue.name}")
+            if not name
+            else Sub(f"${{{ROOT_STACK_NAME_T}}}-{name}")
+        )
     queue = Queue(queue.logical_name, **properties)
     return queue
 
@@ -111,8 +118,9 @@ def define_queue(queue, queues, mono_template=True):
         else:
             retries = 5
         redrive_policy = define_redrive_policy(redrive_target, retries, mono_template)
-    queue = set_queue(queue, properties, redrive_policy)
-    LOG.debug(queue.title)
+    queue.cfn_resource = set_queue(queue, properties, redrive_policy)
+
+    LOG.debug(queue.cfn_resource.title, queue.logical_name)
     return queue
 
 
@@ -129,21 +137,20 @@ def generate_sqs_root_template(settings):
         return None
 
     queues = settings.compose_content[RES_KEY]
-    if (len(list(queues.keys())) * output_per_resource) <= CFN_MAX_OUTPUTS:
+    new_queues = [
+        queues[queue_name] for queue_name in queues if not queues[queue_name].lookup
+    ]
+    if (len(new_queues) * output_per_resource) <= CFN_MAX_OUTPUTS:
         mono_template = True
-    template = build_template("DynamoDB for ECS ComposeX")
-    for queue_name in queues:
-        queue = define_queue(queues[queue_name], queues, mono_template)
-        if queue:
-            values = [
-                (SQS_URL, "Url", Ref(queue)),
-                (SQS_ARN_T, SQS_ARN_T, GetAtt(queue, SQS_ARN_T)),
-                (SQS_NAME_T, SQS_NAME_T, Ref(queue)),
-            ]
-            outputs = ComposeXOutput(queue, values, duplicate_attr=(not mono_template))
+    template = build_template("SQS for ECS ComposeX")
+    for queue in new_queues:
+        define_queue(queue, queues, mono_template)
+        if queue.cfn_resource:
+            queue.init_outputs()
+            queue.generate_outputs()
             if mono_template:
-                template.add_resource(queue)
-                template.add_output(outputs.outputs)
+                template.add_resource(queue.cfn_resource)
+                template.add_output(queue.outputs)
             elif not mono_template:
                 parameters = {}
                 if hasattr(queue, "RedrivePolicy"):
@@ -152,7 +159,7 @@ def generate_sqs_root_template(settings):
                             DLQ_ARN_T: GetAtt(
                                 NONALPHANUM.sub(
                                     "",
-                                    queues[queue_name].definition["Properties"][
+                                    queues[queue.name].definition["Properties"][
                                         "RedrivePolicy"
                                     ]["deadLetterTargetArn"],
                                 ),
@@ -161,12 +168,12 @@ def generate_sqs_root_template(settings):
                         }
                     )
                 queue_template = build_template(
-                    f"Template for SQS queue {queue.title}", [DLQ_ARN]
+                    f"Template for SQS queue {queue.cfn_resource.title}", [DLQ_ARN]
                 )
-                queue_template.add_resource(queue)
-                queue_template.add_output(outputs.outputs)
+                queue_template.add_resource(queue.cfn_resource)
+                queue_template.add_output(queue.outputs)
                 queue_stack = ComposeXStack(
-                    queues[queue_name].logical_name,
+                    queue.logical_name,
                     stack_template=queue_template,
                     stack_parameters=parameters,
                 )
